<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Naam:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Zoeken…</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Alleen in X11 starten</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Opdracht:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Wachten op systeemvak</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Kies een programma</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Automatisch opstarten met systeem</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Locatie: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Heeft voorrang op: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="51"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="37"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="23"/>
        <source>Application Autostart</source>
        <translation>Programma&apos;s automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>Error</source>
        <translation>Foutmelding</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="175"/>
        <source>Please provide Name and Command</source>
        <translation>Voer een naam en opdracht in</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="145"/>
        <location filename="../autostartpage.cpp" line="180"/>
        <source>Name should not start with dot or contain slash</source>
        <translation>De naam mag niet beginnen met een punt of een schuine streep bevatten</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="156"/>
        <location filename="../autostartpage.cpp" line="197"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>‘%1’ bestaat al!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Vensterbeheerder</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <location filename="../basicsettings.ui" line="226"/>
        <source>Search...</source>
        <translation>Zoeken…</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt-modules</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="81"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="88"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Op Wayland kan de beeldgrootte via de vensterbeheerderinstellingen of Kanshi worden aangepast.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Globale beeldgrootte</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Beeldgrootte:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Scherm vergrendelen alvorens in pauze- of slaapstand te gaan</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Pauze-/Slaapstand inschakelen na vergrendelen:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="201"/>
        <source>Use custom screen lock command</source>
        <translation>Eigen schermvergrendelingsopdracht gebruiken</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="197"/>
        <source>Select a window manager</source>
        <translation>Kies een vensterbeheerder</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="212"/>
        <source>Select a screenlocker</source>
        <translation>Kies een schermvergrendeling</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Sessie beëindigen</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Vragen om bevestiging bij beëindigen van sessie</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="47"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="54"/>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="23"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Omgevingsvariabelen (voor ervaren gebruikers)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="34"/>
        <source>Variable Name</source>
        <translation>Naam van variabel</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="39"/>
        <source>Value</source>
        <translation>Waarde</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Actief</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt-sessie-instellingen</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Algemene instellingen</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Gebruikersmappen</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings (Experimental)</source>
        <translation>Waylandinstellingen (experimenteel)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Omgeving (voor ervaren gebruikers)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Herstart van sessie vereist</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Sommige instellingen worden pas toegepast na de volgende aanmelding.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Opslaglocaties van persoonlijke bestanden</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt-sessie-instellingen - Gebruikersmappen</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Er is een fout opgetreden bij het toepassen van de instellingen van de locatie ‘%1’</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Kies een locatie</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Sjablonen</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Openbare map</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Video&apos;s</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Bevat alle bestanden die op uw bureaublad aantreft</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Standaardmap met gedownloade bestanden</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Standaardmap met sjablonen</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Standaardmap met openbaar gedeelde bestanden</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Standaardmap met documenten</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Standaardmap met muziek</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Standaardmap met afbeeldingen/foto&apos;s</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Standaardmap met video&apos;s</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Waylandinstellingen</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor:</source>
        <translation>Wayland-vensterbeheerder:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Zoeken…</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command:</source>
        <translation>Schermvergrendelingsopdracht:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>‘loginctl lock-session’ gebruiken kwin_wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Kies een Wayland-vensterbeheerder</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Kies een Wayland-schermvergrendeling</translation>
    </message>
</context>
</TS>
